Crate consumable

Crate consumable 

Consume the value by replacing it with the default value and returning the previous value

use consumable::*;
 
let mut x : i32 = 42;
assert_eq!(x.consume(), 42);
assert_eq!(x, i32::default());

Traits

Consumable
Consume the value by replacing it with the default value and returning the previous value.